==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/PMCALENDARWEEKDAY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PMCALENDARWEEKDAY_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PMCALENDARWEEKDAY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WEEKOFMONTH"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DAYOFWEEKNUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMCALENDARWEEKDAY_Type", propOrder = {
    "weekofmonth",
    "dayofweeknum"
})
public class PMCALENDARWEEKDAY_Type {

    @XmlElement(name = "WEEKOFMONTH", required = true)
    protected String weekofmonth;
    @XmlElement(name = "DAYOFWEEKNUM")
    protected long dayofweeknum;

    /**
     * Obtient la valeur de la propriété weekofmonth.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWEEKOFMONTH() {
        return weekofmonth;
    }

    /**
     * Définit la valeur de la propriété weekofmonth.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWEEKOFMONTH(String value) {
        this.weekofmonth = value;
    }

    /**
     * Obtient la valeur de la propriété dayofweeknum.
     * 
     */
    public long getDAYOFWEEKNUM() {
        return dayofweeknum;
    }

    /**
     * Définit la valeur de la propriété dayofweeknum.
     * 
     */
    public void setDAYOFWEEKNUM(long value) {
        this.dayofweeknum = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/PMCALENDARWEEKDAY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PMCALENDARWEEKDAY_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PMCALENDARWEEKDAY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WEEKOFMONTH"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DAYOFWEEKNUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMCALENDARWEEKDAY_Type", propOrder = {
    "weekofmonth",
    "dayofweeknum"
})
public class PMCALENDARWEEKDAY_Type {

    @XmlElement(name = "WEEKOFMONTH", required = true)
    protected String weekofmonth;
    @XmlElement(name = "DAYOFWEEKNUM")
    protected long dayofweeknum;

    /**
     * Gets the value of the weekofmonth property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWEEKOFMONTH() {
        return weekofmonth;
    }

    /**
     * Sets the value of the weekofmonth property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWEEKOFMONTH(String value) {
        this.weekofmonth = value;
    }

    /**
     * Gets the value of the dayofweeknum property.
     * 
     */
    public long getDAYOFWEEKNUM() {
        return dayofweeknum;
    }

    /**
     * Sets the value of the dayofweeknum property.
     * 
     */
    public void setDAYOFWEEKNUM(long value) {
        this.dayofweeknum = value;
    }

}
